require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xrdremoteapp',
  dscmeta_resource_friendly_name: 'xRDRemoteApp',
  dscmeta_resource_name: 'MSFT_xRDRemoteApp',
  dscmeta_resource_implementation: '',
  dscmeta_module_name: 'xRemoteDesktopSessionHost',
  dscmeta_module_version: '2.1.0',
  docs: 'The DSC xRDRemoteApp resource type.
         Automatically generated from version 2.1.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_foldername: {
      type: 'Optional[String]',
      desc: 'Specifies the name of the folder that the RemoteApp program appears in on the Remote Desktop Web Access (RD Web Access) webpage and in the Start menu for subscribed RemoteApp and Desktop Connections. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_displayname: {
      type: 'String',
      desc: 'Specifies a name to display to users for the RemoteApp program.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_showinwebaccess: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to show the RemoteApp program in the RD Web Access server, and in RemoteApp and Desktop Connections that the user subscribes to. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_iconpath: {
      type: 'Optional[String]',
      desc: 'Specifies the path to a file containing the icon to display for the RemoteApp program identified by the Alias parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_filepath: {
      type: 'String',
      desc: 'Specifies a path for the executable file for the application. Do not include any environment variables.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Present if the RemoteApp should exist, Absent if it should be removed',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_alias: {
      type: 'String',
      desc: 'Specifies an alias for the RemoteApp program.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_commandlinesetting: {
      type: "Optional[Enum['Allow', 'DoNotAllow', 'Require']]",
      desc: 'Specifies whether the RemoteApp program accepts command-line arguments from the client at connection time. The acceptable values for this parameter are:  Allow, DoNotAllow, Require',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usergroups: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies a list of domain groups that can view the RemoteApp in RD Web Access, and in RemoteApp and Desktop Connections. To allow all users to see a RemoteApp program, provide a value of Null.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_filevirtualpath: {
      type: 'Optional[String]',
      desc: 'Specifies a path for the application executable file. This path resolves to the same location as the value of the FilePath parameter, but it can include environment variables. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_collectionname: {
      type: 'String',
      desc: 'Specifies the name of the personal virtual desktop collection or session collection. The cmdlet publishes the RemoteApp program to this collection. ',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_iconindex: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: "Specifies the index within the icon file (specified by the IconPath parameter) where the RemoteApp program's icon can be found.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_requiredcommandline: {
      type: 'Optional[String]',
      desc: 'Specifies a string that contains command-line arguments that the client can use at connection time with the RemoteApp program. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
