require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xrdsessioncollectionconfiguration',
  dscmeta_resource_friendly_name: 'xRDSessionCollectionConfiguration',
  dscmeta_resource_name: 'MSFT_xRDSessionCollectionConfiguration',
  dscmeta_resource_implementation: '',
  dscmeta_module_name: 'xRemoteDesktopSessionHost',
  dscmeta_module_version: '2.1.0',
  docs: 'The DSC xRDSessionCollectionConfiguration resource type.
         Automatically generated from version 2.1.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_collectionname: {
      type: 'String',
      desc: 'Specifies the name of a session collection. ',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_diskpath: {
      type: 'Optional[String]',
      desc: 'Specifies the target to store the User Profile Disks ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_authenticateusingnla: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether to use Network Level Authentication (NLA). If this value is $True, Remote Desktop uses NLA to authenticate a user before the user sees a logon screen. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_collectiondescription: {
      type: 'Optional[String]',
      desc: 'Specifies a description of the session collection. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_automaticreconnectionenabled: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether the Remote Desktop client attempts to reconnect after a connection interruption. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maxredirectedmonitors: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the maximum number of client monitors that an RD Session Host server can redirect to a remote session. The highest value for this parameter is 16.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_activesessionlimitmin: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the maximum time, in minutes, an active session runs. After this period, the RD Session Host server ends the session. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_maxuserprofiledisksizegb: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the maximum size in GB for a User Profile Disk ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_disconnectedsessionlimitmin: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies a length of time, in minutes. After client disconnection from a session for this period, the RD Session Host ends the session.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_connectionbroker: {
      type: 'Optional[String]',
      desc: 'Specifies the Remote Desktop Connection Broker (RD Connection Broker) server for a Remote Desktop deployment.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_excludefilepath: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies a list of strings for files to exclude from the user profile disk ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_clientdeviceredirectionoptions: {
      type: 'Optional[String]',
      desc: 'Specifies a type of client device to be redirected to an RD Session Host server in this session collection. The acceptable values for this parameter are: None, AudioVideoPlayBack, AudioRecording, COMPort, PlugAndPlayDevice, SmartCard, Clipboard, LPTPort, Drive, TimeZone.  You can use binary-or to combine two or more values of this enum to specify multiple client device types.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_securitylayer: {
      type: 'Optional[String]',
      desc: 'Specifies which security protocol to use. The acceptable values for this parameter are:  RDP, Negotiate, SSL.  The default value is Negotiate.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_idlesessionlimitmin: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the length of time, in minutes, to wait before an RD Session Host logs off or disconnects an idle session. The BrokenConnectionAction parameter determines whether to log off or disconnect. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_clientprinterredirected: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether to use client printer redirection, which routes print jobs from the Remote Desktop session to a printer attached to the client computer.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_includefolderpath: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies a list of strings for folders to include in the user profile disk ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_brokenconnectionaction: {
      type: 'Optional[String]',
      desc: 'Specifies an action for an RD Session Host server to take after a connection interruption. The acceptable values for this parameter are: None, Disconnect, LogOff.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_includefilepath: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies a list of strings for files to include in the user profile disk ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_encryptionlevel: {
      type: 'Optional[String]',
      desc: 'Specifies the level of data encryption used for a Remote Desktop session. The acceptable values for this parameter are: Low, ClientCompatible, High, FipsCompliant. The default value is ClientCompatible.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enableuserprofiledisk: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if this collection uses UserProfileDisks ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_excludefolderpath: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies a list of strings for folders to exclude from the user profile disk ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_customrdpproperty: {
      type: 'Optional[String]',
      desc: 'Specifies Remote Desktop Protocol (RDP) settings to include in the .rdp files for all Windows Server 2012 RemoteApp programs and remote desktops published in this collection. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_temporaryfoldersdeletedonexit: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to delete temporary folders from the RD Session Host server for a disconnected session. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_usergroup: {
      type: 'Optional[String]',
      desc: 'Specifies a domain group authorized to connect to the RD Session Host servers in a session collection. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_clientprinterasdefault: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether to use the client printer or server printer as the default printer. If this value is $True, use the client printer as default. If this value is $False, use the server as default.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_rdeasyprintdriverenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to enable the Remote Desktop Easy Print driver.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
